@@ -4,10 +4,14 @@ Entity classes for representing the various Strava datatypes.
 from __future__ import division, absolute_import, print_function, unicode_literals
 import abc
 import logging
-from collections import Sequence
 
 import six
 
+if six.PY2:
+    from collections import Sequence
+else:
+    from collections.abc import Sequence
+
 from stravalib import exc
 from stravalib import unithelper as uh
 
@@ -40,10 +44,11 @@ class BaseEntity(object):
         :rtype: Dict[str, Any]
         """
         d = {}
-        for attrname, attr in self.__class__.__dict__.items():
-            if isinstance(attr, Attribute):
-                value = getattr(self, attrname)
-                d[attrname] = attr.marshal(value)
+        for cls in self.__class__.__mro__:
+            for attrname, attr in cls.__dict__.items():
+                if attrname not in d and isinstance(attr, Attribute):
+                    value = getattr(self, attrname)
+                    d[attrname] = attr.marshal(value)
         return d
 
     def from_dict(self, d):
@@ -559,6 +564,7 @@ class Split(BaseEntity):
     split = Attribute(int)  #: Which split number
     pace_zone = Attribute(int)  #: (undocumented)
     average_speed = Attribute(float, units=uh.meters_per_second)
+    average_grade_adjusted_speed = Attribute(float, units=uh.meters_per_second)
 
     def __repr__(self):
         return '<Split split={} distance={} elapsed_time={}>'.format(self.split, self.distance, self.elapsed_time)
@@ -720,12 +726,6 @@ class Activity(LoadableEntity):
     Represents an activity (ride, run, etc.).
     """
     # "Constants" for types of activities
-    RIDE = "Ride"
-    RUN = "Run"
-    SWIM = "Swim"
-    HIKE = "Hike"
-    WALK = "Walk"
-
     ALPINESKI = "AlpineSki"
     BACKCOUNTRYSKI = "BackcountrySki"
     CANOEING = "Canoeing"
@@ -733,21 +733,34 @@ class Activity(LoadableEntity):
     CROSSFIT = "Crossfit"
     EBIKERIDE = "EBikeRide"
     ELLIPTICAL = "Elliptical"
+    GOLF = "Golf"
+    HANDCLYCLE = "Handcycle"
+    HIKE = "Hike"
     ICESKATE = "IceSkate"
     INLINESKATE = "InlineSkate"
     KAYAKING = "Kayaking"
     KITESURF = "Kitesurf"
     NORDICSKI = "NordicSki"
+    RIDE = "Ride"
     ROCKCLIMBING = "RockClimbing"
     ROLLERSKI = "RollerSki"
     ROWING = "Rowing"
+    RUN = "Run"
+    SAIL = "Sail"
+    SKATEBOARD = "Skateboard"
     SNOWBOARD = "Snowboard"
     SNOWSHOE = "Snowshoe"
+    SOCCER = "Soccer"
     STAIRSTEPPER = "StairStepper"
     STANDUPPADDLING = "StandUpPaddling"
     SURFING = "Surfing"
+    SWIM = "Swim"
+    VELOMOBILE = "Velomobile"
     VIRTUALRIDE = "VirtualRide"
+    VIRTUALRUN = "VirtualRun"
+    WALK = "Walk"
     WEIGHTTRAINING = "WeightTraining"
+    WHEELCHAIR = "Wheelchair"
     WINDSURF = "Windsurf"
     WORKOUT = "Workout"
     YOGA = "Yoga"
@@ -760,12 +773,11 @@ class Activity(LoadableEntity):
     _laps = None
     _related = None
 
-    TYPES = (RIDE, RUN, SWIM, WALK, ALPINESKI, BACKCOUNTRYSKI, CANOEING,
-             CROSSCOUNTRYSKIING, CROSSFIT, EBIKERIDE, ELLIPTICAL, HIKE, ICESKATE,
-             INLINESKATE, KAYAKING, KITESURF, NORDICSKI, ROCKCLIMBING,
-             ROLLERSKI, ROWING, SNOWBOARD, SNOWSHOE, STAIRSTEPPER,
-             STANDUPPADDLING, SURFING, VIRTUALRIDE, WEIGHTTRAINING, WINDSURF, WORKOUT, YOGA)
-
+    TYPES = (ALPINESKI, BACKCOUNTRYSKI, CANOEING, CROSSCOUNTRYSKIING, CROSSFIT, EBIKERIDE,
+             ELLIPTICAL, GOLF, HANDCLYCLE, HIKE, ICESKATE, INLINESKATE, KAYAKING, KITESURF,
+             NORDICSKI, RIDE, ROCKCLIMBING, ROLLERSKI, ROWING, RUN, SAIL, SKATEBOARD, SNOWBOARD,
+             SNOWSHOE, SOCCER, STAIRSTEPPER, STANDUPPADDLING, SURFING, SWIM, VELOMOBILE,
+             VIRTUALRIDE, VIRTUALRUN, WALK, WEIGHTTRAINING, WHEELCHAIR, WINDSURF, WORKOUT, YOGA)
     guid = Attribute(six.text_type, (SUMMARY, DETAILED))  #: (undocumented)
 
     external_id = Attribute(six.text_type, (SUMMARY, DETAILED))  #: An external ID for the activity (relevant when specified during upload).
